==> org-lsst-sal-cccamera-2.5.0-sources.jar: org/lsst/sal/cccamera/event/Fcs_StepperMotor_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Fcs_StepperMotor_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double motorencoder_warnHi;

  private final double motorencoder_warnLo;

  private final double motorencoder_limitHi;

  private final double motorencoder_limitLo;

  private final double motortemperature_warnHi;

  private final double motortemperature_warnLo;

  private final double motortemperature_limitHi;

  private final double motortemperature_limitLo;

  public Fcs_StepperMotor_LimitsConfigurationEvent(int priority, String version,
      double motorencoder_warnHi, double motorencoder_warnLo, double motorencoder_limitHi,
      double motorencoder_limitLo, double motortemperature_warnHi, double motortemperature_warnLo,
      double motortemperature_limitHi, double motortemperature_limitLo) {
    super (priority);
    this.version = version;
    this.motorencoder_warnHi = motorencoder_warnHi;
    this.motorencoder_warnLo = motorencoder_warnLo;
    this.motorencoder_limitHi = motorencoder_limitHi;
    this.motorencoder_limitLo = motorencoder_limitLo;
    this.motortemperature_warnHi = motortemperature_warnHi;
    this.motortemperature_warnLo = motortemperature_warnLo;
    this.motortemperature_limitHi = motortemperature_limitHi;
    this.motortemperature_limitLo = motortemperature_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getMotorencoder_warnHi() {
    return motorencoder_warnHi;
  }

  public double getMotorencoder_warnLo() {
    return motorencoder_warnLo;
  }

  public double getMotorencoder_limitHi() {
    return motorencoder_limitHi;
  }

  public double getMotorencoder_limitLo() {
    return motorencoder_limitLo;
  }

  public double getMotortemperature_warnHi() {
    return motortemperature_warnHi;
  }

  public double getMotortemperature_warnLo() {
    return motortemperature_warnLo;
  }

  public double getMotortemperature_limitHi() {
    return motortemperature_limitHi;
  }

  public double getMotortemperature_limitLo() {
    return motortemperature_limitLo;
  }

  @Override
  public String toString() {
    return "Fcs_StepperMotor_LimitsConfigurationEvent{" + "version=" + version +
        ", motorencoder_warnHi=" + motorencoder_warnHi +
        ", motorencoder_warnLo=" + motorencoder_warnLo +
        ", motorencoder_limitHi=" + motorencoder_limitHi +
        ", motorencoder_limitLo=" + motorencoder_limitLo +
        ", motortemperature_warnHi=" + motortemperature_warnHi +
        ", motortemperature_warnLo=" + motortemperature_warnLo +
        ", motortemperature_limitHi=" + motortemperature_limitHi +
        ", motortemperature_limitLo=" + motortemperature_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double motorencoder_warnHi;

    private double motorencoder_warnLo;

    private double motorencoder_limitHi;

    private double motorencoder_limitLo;

    private double motortemperature_warnHi;

    private double motortemperature_warnLo;

    private double motortemperature_limitHi;

    private double motortemperature_limitLo;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder motorencoder_warnHi(double motorencoder_warnHi) {
      this.motorencoder_warnHi = motorencoder_warnHi;
      return this;
    }

    public Builder motorencoder_warnLo(double motorencoder_warnLo) {
      this.motorencoder_warnLo = motorencoder_warnLo;
      return this;
    }

    public Builder motorencoder_limitHi(double motorencoder_limitHi) {
      this.motorencoder_limitHi = motorencoder_limitHi;
      return this;
    }

    public Builder motorencoder_limitLo(double motorencoder_limitLo) {
      this.motorencoder_limitLo = motorencoder_limitLo;
      return this;
    }

    public Builder motortemperature_warnHi(double motortemperature_warnHi) {
      this.motortemperature_warnHi = motortemperature_warnHi;
      return this;
    }

    public Builder motortemperature_warnLo(double motortemperature_warnLo) {
      this.motortemperature_warnLo = motortemperature_warnLo;
      return this;
    }

    public Builder motortemperature_limitHi(double motortemperature_limitHi) {
      this.motortemperature_limitHi = motortemperature_limitHi;
      return this;
    }

    public Builder motortemperature_limitLo(double motortemperature_limitLo) {
      this.motortemperature_limitLo = motortemperature_limitLo;
      return this;
    }

    public Fcs_StepperMotor_LimitsConfigurationEvent build() {
      return new Fcs_StepperMotor_LimitsConfigurationEvent(priority, version, motorencoder_warnHi, motorencoder_warnLo, motorencoder_limitHi, motorencoder_limitLo, motortemperature_warnHi, motortemperature_warnLo, motortemperature_limitHi, motortemperature_limitLo);
    }
  }
}

==> org-lsst-sal-cccamera-2.5.8-sources.jar: org/lsst/sal/cccamera/event/Fcs_StepperMotor_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Fcs_StepperMotor_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double motorencoder_warnHi;

  private final double motorencoder_warnLo;

  private final double motorencoder_limitHi;

  private final double motorencoder_limitLo;

  private final double motortemperature_warnHi;

  private final double motortemperature_warnLo;

  private final double motortemperature_limitHi;

  private final double motortemperature_limitLo;

  public Fcs_StepperMotor_LimitsConfigurationEvent(String version, double motorencoder_warnHi,
      double motorencoder_warnLo, double motorencoder_limitHi, double motorencoder_limitLo,
      double motortemperature_warnHi, double motortemperature_warnLo,
      double motortemperature_limitHi, double motortemperature_limitLo) {
    this.version = version;
    this.motorencoder_warnHi = motorencoder_warnHi;
    this.motorencoder_warnLo = motorencoder_warnLo;
    this.motorencoder_limitHi = motorencoder_limitHi;
    this.motorencoder_limitLo = motorencoder_limitLo;
    this.motortemperature_warnHi = motortemperature_warnHi;
    this.motortemperature_warnLo = motortemperature_warnLo;
    this.motortemperature_limitHi = motortemperature_limitHi;
    this.motortemperature_limitLo = motortemperature_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getMotorencoder_warnHi() {
    return motorencoder_warnHi;
  }

  public double getMotorencoder_warnLo() {
    return motorencoder_warnLo;
  }

  public double getMotorencoder_limitHi() {
    return motorencoder_limitHi;
  }

  public double getMotorencoder_limitLo() {
    return motorencoder_limitLo;
  }

  public double getMotortemperature_warnHi() {
    return motortemperature_warnHi;
  }

  public double getMotortemperature_warnLo() {
    return motortemperature_warnLo;
  }

  public double getMotortemperature_limitHi() {
    return motortemperature_limitHi;
  }

  public double getMotortemperature_limitLo() {
    return motortemperature_limitLo;
  }

  @Override
  public String toString() {
    return "Fcs_StepperMotor_LimitsConfigurationEvent{" + "version=" + version +
        ", motorencoder_warnHi=" + motorencoder_warnHi +
        ", motorencoder_warnLo=" + motorencoder_warnLo +
        ", motorencoder_limitHi=" + motorencoder_limitHi +
        ", motorencoder_limitLo=" + motorencoder_limitLo +
        ", motortemperature_warnHi=" + motortemperature_warnHi +
        ", motortemperature_warnLo=" + motortemperature_warnLo +
        ", motortemperature_limitHi=" + motortemperature_limitHi +
        ", motortemperature_limitLo=" + motortemperature_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double motorencoder_warnHi;

    private double motorencoder_warnLo;

    private double motorencoder_limitHi;

    private double motorencoder_limitLo;

    private double motortemperature_warnHi;

    private double motortemperature_warnLo;

    private double motortemperature_limitHi;

    private double motortemperature_limitLo;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder motorencoder_warnHi(double motorencoder_warnHi) {
      this.motorencoder_warnHi = motorencoder_warnHi;
      return this;
    }

    public Builder motorencoder_warnLo(double motorencoder_warnLo) {
      this.motorencoder_warnLo = motorencoder_warnLo;
      return this;
    }

    public Builder motorencoder_limitHi(double motorencoder_limitHi) {
      this.motorencoder_limitHi = motorencoder_limitHi;
      return this;
    }

    public Builder motorencoder_limitLo(double motorencoder_limitLo) {
      this.motorencoder_limitLo = motorencoder_limitLo;
      return this;
    }

    public Builder motortemperature_warnHi(double motortemperature_warnHi) {
      this.motortemperature_warnHi = motortemperature_warnHi;
      return this;
    }

    public Builder motortemperature_warnLo(double motortemperature_warnLo) {
      this.motortemperature_warnLo = motortemperature_warnLo;
      return this;
    }

    public Builder motortemperature_limitHi(double motortemperature_limitHi) {
      this.motortemperature_limitHi = motortemperature_limitHi;
      return this;
    }

    public Builder motortemperature_limitLo(double motortemperature_limitLo) {
      this.motortemperature_limitLo = motortemperature_limitLo;
      return this;
    }

    public Fcs_StepperMotor_LimitsConfigurationEvent build() {
      return new Fcs_StepperMotor_LimitsConfigurationEvent(version, motorencoder_warnHi, motorencoder_warnLo, motorencoder_limitHi, motorencoder_limitLo, motortemperature_warnHi, motortemperature_warnLo, motortemperature_limitHi, motortemperature_limitLo);
    }
  }
}
